@@ -1,10 +1,10 @@
 use std::path::PathBuf;
 
 use chrono::prelude::*;
-use chrono::Duration;
-use chrono_english::*;
+use chrono::TimeDelta;
 use clap::ArgAction;
 use clap::{Parser, ValueEnum, ValueHint};
+use interim::*;
 
 use pueue_lib::network::message::Signal;
 
@@ -45,7 +45,7 @@ pub enum SubCommand {
         #[arg(short, long, conflicts_with = "immediate")]
         stashed: bool,
 
-        /// Prevents the task from being enqueued until <delay> elapses. See "enqueue" for accepted formats.
+        /// Prevents the task from being enqueued until 'delay' elapses. See "enqueue" for accepted formats.
         #[arg(name = "delay", short, long, conflicts_with = "immediate", value_parser = parse_delay_until)]
         delay_until: Option<DateTime<Local>>,
 
@@ -126,7 +126,7 @@ pub enum SubCommand {
         /// Enqueue these specific tasks.
         task_ids: Vec<usize>,
 
-        /// Delay enqueuing these tasks until <delay> elapses. See DELAY FORMAT below.
+        /// Delay enqueuing these tasks until 'delay' elapses. See DELAY FORMAT below.
         #[arg(name = "delay", short, long, value_parser = parse_delay_until)]
         delay_until: Option<DateTime<Local>>,
     },
@@ -528,6 +528,7 @@ pub enum Shell {
     Fish,
     PowerShell,
     Zsh,
+    Nushell,
 }
 
 #[derive(Parser, Debug)]
@@ -562,7 +563,9 @@ pub struct CliArguments {
 
 fn parse_delay_until(src: &str) -> Result<DateTime<Local>, String> {
     if let Ok(seconds) = src.parse::<i64>() {
-        let delay_until = Local::now() + Duration::seconds(seconds);
+        let delay_until = Local::now()
+            + TimeDelta::try_seconds(seconds)
+                .ok_or("Failed to get timedelta from {seconds} seconds")?;
         return Ok(delay_until);
     }
 
