@@ -11,11 +11,12 @@ use rstest::rstest;
 #[case("bash")]
 #[case("fish")]
 #[case("power-shell")]
+#[case("nushell")]
 #[test]
 fn autocompletion_generation(#[case] shell: &'static str) -> Result<()> {
     let output = Command::cargo_bin("pueue")?
         .arg("completions")
-        .arg("zsh")
+        .arg(shell)
         .arg("./")
         .stdout(Stdio::piped())
         .stderr(Stdio::piped())
