@@ -23,14 +23,10 @@ fn test_restore_from_old_state() -> Result<()> {
         .join("v0.15.0_settings.yml");
 
     // Open v0.15.0 file and ensure the settings file can be read.
-    let (settings, config_found) = Settings::read(&Some(old_settings_path))
+    let (_settings, config_found) = Settings::read(&Some(old_settings_path))
         .context("Failed to read old config with defaults:")?;
 
     assert!(config_found);
-    // Legacy group setting exists
-    #[allow(deprecated)]
-    let groups = settings.daemon.groups.unwrap();
-    assert_eq!(*groups.get("webhook").unwrap(), 1);
 
     Ok(())
 }
